summaryrefslogtreecommitdiffstats
path: root/filters/kspread
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:38:41 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:38:41 -0600
commitf0de9e167e289ab7dc33e57f077c1f04ec7c68c8 (patch)
tree1fc538e179833e62caec21956bfe47a252be5a72 /filters/kspread
parent11191ef0b9908604d1d7aaca382b011ef22c454c (diff)
downloadkoffice-f0de9e167e289ab7dc33e57f077c1f04ec7c68c8.tar.gz
koffice-f0de9e167e289ab7dc33e57f077c1f04ec7c68c8.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'filters/kspread')
-rw-r--r--filters/kspread/applixspread/applixspreadimport.cc6
-rw-r--r--filters/kspread/applixspread/status.html20
-rw-r--r--filters/kspread/csv/csvdialog.cpp12
-rw-r--r--filters/kspread/csv/csvexportdialog.cpp12
-rw-r--r--filters/kspread/csv/dialogui.ui4
-rw-r--r--filters/kspread/csv/exportdialogui.ui2
-rw-r--r--filters/kspread/dbase/dbase.cpp4
-rw-r--r--filters/kspread/excel/import/excelimport.cc24
-rw-r--r--filters/kspread/excel/sidewinder/excel.cpp36
-rw-r--r--filters/kspread/excel/sidewinder/excel.h12
-rw-r--r--filters/kspread/excel/sidewinder/format.cpp28
-rw-r--r--filters/kspread/excel/sidewinder/format.h36
-rw-r--r--filters/kspread/excel/sidewinder/pole.cpp22
-rw-r--r--filters/kspread/gnumeric/gnumeric.xsd10
-rw-r--r--filters/kspread/gnumeric/gnumericexport.cc2
-rw-r--r--filters/kspread/html/exportdialog.cc2
-rw-r--r--filters/kspread/html/htmlexport.cc10
-rw-r--r--filters/kspread/latex/export/fileheader.cc4
-rw-r--r--filters/kspread/latex/export/kspreadlatexexportdiaImpl.cc2
-rw-r--r--filters/kspread/latex/export/map.cc2
-rw-r--r--filters/kspread/latex/export/xmlparser.cc12
-rw-r--r--filters/kspread/opencalc/opencalcexport.cc6
-rw-r--r--filters/kspread/opencalc/opencalcimport.cc4
-rw-r--r--filters/kspread/opencalc/opencalcstyleexport.cc18
-rw-r--r--filters/kspread/opencalc/status.html4
25 files changed, 147 insertions, 147 deletions
diff --git a/filters/kspread/applixspread/applixspreadimport.cc b/filters/kspread/applixspread/applixspreadimport.cc
index 2f15eeedf..5b88d11c1 100644
--- a/filters/kspread/applixspread/applixspreadimport.cc
+++ b/filters/kspread/applixspread/applixspreadimport.cc
@@ -390,7 +390,7 @@ KoFilter::ConversionStatus APPLIXSPREADImport::convert( const TQCString& from, c
//kdDebug()<< " Type (%2d) >%s< ",
// nn, (*it).latin1() );
nn++;
- // Grep horizontal tqalignment
+ // Grep horizontal alignment
if ( (*it) == "1")
{
kdDebug()<< " = left align\n";
@@ -407,7 +407,7 @@ KoFilter::ConversionStatus APPLIXSPREADImport::convert( const TQCString& from, c
align = 2; // center
}
- // Grep verticale tqalignment
+ // Grep verticale alignment
else if ( (*it) == "VT")
{
kdDebug()<<" = top valign\n";
@@ -1268,7 +1268,7 @@ APPLIXSPREADImport::readHeader (TQTextStream &stream)
TQMessageBox::critical (0L, "Applix spreadsheet header problem",
TQString ("The Applix Spreadsheet header is not correct. "
"May be it is not an applix spreadsheet file! <BR>"
- "This is the header line I did read:<BR><B>%1</B>").tqarg(mystr.latin1()),
+ "This is the header line I did read:<BR><B>%1</B>").arg(mystr.latin1()),
"Okay");
diff --git a/filters/kspread/applixspread/status.html b/filters/kspread/applixspread/status.html
index 968bf333e..c944ef5c0 100644
--- a/filters/kspread/applixspread/status.html
+++ b/filters/kspread/applixspread/status.html
@@ -53,7 +53,7 @@
- tests the headline of the document<br>
- converts &lt;, &gt;, &amp;, to &amp;lt; &amp;gt; &amp;amp;<br>
- converts all applix special characters<br>
- - converts fontsize, fontcolor, horizontal and vertical tqalignment, bold, italic, underline<br>
+ - converts fontsize, fontcolor, horizontal and vertical alignment, bold, italic, underline<br>
- eats long text strings (more than one row in inputfile)<br>
- converts different tables inside of one document<br>
- cellformat: background color, brushstyles, brushcolor<br>
@@ -352,43 +352,43 @@
<spacer size="20"><U>6.1.1. Part 1 - Alignment format</U><BR>
- <spacer size="30">This is the tqalignment format for vertical, horizontal tqalignment<BR>
+ <spacer size="30">This is the alignment format for vertical, horizontal alignment<BR>
<spacer size="30">
<TABLE CELLPADDING="0" BORDER="0">
<TR>
<TD>6.1.1.1&nbsp;&nbsp;</TD>
<TD><B>1</B></TD>
- <TD>horizontal tqalignment</TD>
+ <TD>horizontal alignment</TD>
<TD>left</TD>
</TR>
<TR>
<TD>6.1.1.2&nbsp;&nbsp;</TD>
<TD><B>2</B></TD>
- <TD>horizontal tqalignment</TD>
+ <TD>horizontal alignment</TD>
<TD>right</TD>
</TR>
<TR>
<TD>6.1.1.3&nbsp;&nbsp;</TD>
<TD><B>3</B></TD>
- <TD>horizontal tqalignment</TD>
+ <TD>horizontal alignment</TD>
<TD>center</TD>
</TR>
<TR>
<TD>6.1.1.4&nbsp;&nbsp;</TD>
<TD><B>VT</B></TD>
- <TD>vertical tqalignment</TD>
+ <TD>vertical alignment</TD>
<TD>top</TD>
</TR>
<TR>
<TD>6.1.1.5&nbsp;&nbsp;</TD>
<TD><B>VC</B></TD>
- <TD>vertical tqalignment</TD>
+ <TD>vertical alignment</TD>
<TD>center</TD>
</TR>
<TR>
<TD>6.1.1.5&nbsp;&nbsp;</TD>
<TD><B>VB</B></TD>
- <TD>vertical tqalignment</TD>
+ <TD>vertical alignment</TD>
<TD>bottom</TD>
</TR>
<TR>
@@ -402,7 +402,7 @@
<spacer size="20"><U>6.1.2. Part 2 - Text format</U><BR>
- <spacer size="30">This is the tqalignment format for the text<BR>
+ <spacer size="30">This is the alignment format for the text<BR>
<spacer size="30">
<TABLE CELLPADDING="0" BORDER="0">
<TR>
@@ -441,7 +441,7 @@
<spacer size="20"><U>6.1.3. Part 3 - Cell format</U><BR>
- <spacer size="30">This is the tqalignment format for the text<BR>
+ <spacer size="30">This is the alignment format for the text<BR>
<spacer size="30">
<TABLE CELLPADDING="0" BORDER="0">
<TR>
diff --git a/filters/kspread/csv/csvdialog.cpp b/filters/kspread/csv/csvdialog.cpp
index 95f4727cb..0464b782a 100644
--- a/filters/kspread/csv/csvdialog.cpp
+++ b/filters/kspread/csv/csvdialog.cpp
@@ -60,14 +60,14 @@ CSVDialog::CSVDialog(TQWidget* parent, TQByteArray& fileArray, const TQString /*
kapp->restoreOverrideCursor();
TQStringList encodings;
- encodings << i18n( "Descriptive encoding name", "Recommended ( %1 )" ).tqarg( "UTF-8" );
- encodings << i18n( "Descriptive encoding name", "Locale ( %1 )" ).tqarg( TQTextCodec::codecForLocale()->name() );
+ encodings << i18n( "Descriptive encoding name", "Recommended ( %1 )" ).arg( "UTF-8" );
+ encodings << i18n( "Descriptive encoding name", "Locale ( %1 )" ).arg( TQTextCodec::codecForLocale()->name() );
encodings += KGlobal::charsets()->descriptiveEncodingNames();
// Add a few non-standard encodings, which might be useful for text files
const TQString description(i18n("Descriptive encoding name","Other ( %1 )"));
- encodings << description.tqarg("Apple Roman"); // Apple
- encodings << description.tqarg("IBM 850") << description.tqarg("IBM 866"); // MS DOS
- encodings << description.tqarg("CP 1258"); // Windows
+ encodings << description.arg("Apple Roman"); // Apple
+ encodings << description.arg("IBM 850") << description.arg("IBM 866"); // MS DOS
+ encodings << description.arg("CP 1258"); // Windows
m_dialog->comboBoxEncoding->insertStringList(encodings);
m_formatList << i18n( "Text" );
@@ -613,7 +613,7 @@ TQTextCodec* CSVDialog::getCodec(void) const
// Default: UTF-8
kdWarning(30502) << "Cannot find encoding:" << strCodec << endl;
// ### TODO: what parent to use?
- KMessageBox::error( 0, i18n("Cannot find encoding: %1").tqarg( strCodec ) );
+ KMessageBox::error( 0, i18n("Cannot find encoding: %1").arg( strCodec ) );
return 0;
}
diff --git a/filters/kspread/csv/csvexportdialog.cpp b/filters/kspread/csv/csvexportdialog.cpp
index a4ef13472..285565e7d 100644
--- a/filters/kspread/csv/csvexportdialog.cpp
+++ b/filters/kspread/csv/csvexportdialog.cpp
@@ -57,14 +57,14 @@ CSVExportDialog::CSVExportDialog( TQWidget * parent )
kapp->restoreOverrideCursor();
TQStringList encodings;
- encodings << i18n( "Descriptive encoding name", "Recommended ( %1 )" ).tqarg( "UTF-8" );
- encodings << i18n( "Descriptive encoding name", "Locale ( %1 )" ).tqarg( TQTextCodec::codecForLocale()->name() );
+ encodings << i18n( "Descriptive encoding name", "Recommended ( %1 )" ).arg( "UTF-8" );
+ encodings << i18n( "Descriptive encoding name", "Locale ( %1 )" ).arg( TQTextCodec::codecForLocale()->name() );
encodings += KGlobal::charsets()->descriptiveEncodingNames();
// Add a few non-standard encodings, which might be useful for text files
const TQString description(i18n("Descriptive encoding name","Other ( %1 )"));
- encodings << description.tqarg("Apple Roman"); // Apple
- encodings << description.tqarg("IBM 850") << description.tqarg("IBM 866"); // MS DOS
- encodings << description.tqarg("CP 1258"); // Windows
+ encodings << description.arg("Apple Roman"); // Apple
+ encodings << description.arg("IBM 850") << description.arg("IBM 866"); // MS DOS
+ encodings << description.arg("CP 1258"); // Windows
m_dialog->comboBoxEncoding->insertStringList(encodings);
@@ -306,7 +306,7 @@ TQTextCodec* CSVExportDialog::getCodec(void) const
// Default: UTF-8
kdWarning(30502) << "Cannot find encoding:" << strCodec << endl;
// ### TODO: what parent to use?
- KMessageBox::error( 0, i18n("Cannot find encoding: %1").tqarg( strCodec ) );
+ KMessageBox::error( 0, i18n("Cannot find encoding: %1").arg( strCodec ) );
return 0;
}
diff --git a/filters/kspread/csv/dialogui.ui b/filters/kspread/csv/dialogui.ui
index 5e7090078..6f7633ecd 100644
--- a/filters/kspread/csv/dialogui.ui
+++ b/filters/kspread/csv/dialogui.ui
@@ -379,7 +379,7 @@
<property name="textFormat">
<enum>AutoText</enum>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>WordBreak|AlignCenter</set>
</property>
</widget>
@@ -428,7 +428,7 @@
<property name="textFormat">
<enum>AutoText</enum>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>WordBreak|AlignCenter</set>
</property>
</widget>
diff --git a/filters/kspread/csv/exportdialogui.ui b/filters/kspread/csv/exportdialogui.ui
index a60c3d651..d02f67126 100644
--- a/filters/kspread/csv/exportdialogui.ui
+++ b/filters/kspread/csv/exportdialogui.ui
@@ -254,7 +254,7 @@
<property name="text">
<string>&lt;SHEETNAME&gt; gets replaced by the name of the next sheet.</string>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>WordBreak|AlignVCenter</set>
</property>
</widget>
diff --git a/filters/kspread/dbase/dbase.cpp b/filters/kspread/dbase/dbase.cpp
index acc1e27d6..2c8ba3b87 100644
--- a/filters/kspread/dbase/dbase.cpp
+++ b/filters/kspread/dbase/dbase.cpp
@@ -165,7 +165,7 @@ bool DBase::load( const TQString& filename )
}
// set the index to the first record
- m_stream.tqdevice()->at( m_headerLength );
+ m_stream.device()->at( m_headerLength );
return true;
}
@@ -184,7 +184,7 @@ TQStringList DBase::readRecord( unsigned recno )
// seek to where the record is
unsigned filepos = m_headerLength + recno * m_recordLength;
- m_stream.tqdevice()->at( filepos );
+ m_stream.device()->at( filepos );
// first char == '*' means the record is deleted
// so we just skip it
diff --git a/filters/kspread/excel/import/excelimport.cc b/filters/kspread/excel/import/excelimport.cc
index e705a9338..19f5888bf 100644
--- a/filters/kspread/excel/import/excelimport.cc
+++ b/filters/kspread/excel/import/excelimport.cc
@@ -348,7 +348,7 @@ void ExcelImport::Private::processSheetForBody( Sheet* sheet, KoXmlWriter* xmlWr
xmlWriter->addAttribute( "table:name", string( sheet->name() ).string() );
xmlWriter->addAttribute( "table:print", "false" );
xmlWriter->addAttribute( "table:protected", "false" );
- xmlWriter->addAttribute( "table:style-name", TQString("ta%1").tqarg(sheetFormatIndex));
+ xmlWriter->addAttribute( "table:style-name", TQString("ta%1").arg(sheetFormatIndex));
sheetFormatIndex++;
unsigned ci = 0;
@@ -397,7 +397,7 @@ void ExcelImport::Private::processSheetForStyle( Sheet* sheet, KoXmlWriter* xmlW
xmlWriter->startElement( "style:style" );
xmlWriter->addAttribute( "style:family", "table" );
xmlWriter->addAttribute( "style:master-page-name", "Default" );
- xmlWriter->addAttribute( "style:name", TQString("ta%1").tqarg(sheetFormatIndex) );
+ xmlWriter->addAttribute( "style:name", TQString("ta%1").arg(sheetFormatIndex) );
sheetFormatIndex++;
xmlWriter->startElement( "style:table-properties" );
@@ -450,7 +450,7 @@ void ExcelImport::Private::processColumnForBody( Column* column, int repeat, KoX
xmlWriter->addAttribute( "table:default-style-name", "Default" );
xmlWriter->addAttribute( "table:visibility", column->visible() ? "visible" : "collapse" );
if(repeat > 1) xmlWriter->addAttribute( "table:number-columns-repeated", repeat );
- xmlWriter->addAttribute( "table:style-name", TQString("co%1").tqarg(columnFormatIndex) );
+ xmlWriter->addAttribute( "table:style-name", TQString("co%1").arg(columnFormatIndex) );
columnFormatIndex++;
xmlWriter->endElement(); // table:table-column
@@ -463,12 +463,12 @@ void ExcelImport::Private::processColumnForStyle( Column* column, int /*repeat*/
xmlWriter->startElement( "style:style" );
xmlWriter->addAttribute( "style:family", "table-column" );
- xmlWriter->addAttribute( "style:name", TQString("co%1").tqarg(columnFormatIndex) );
+ xmlWriter->addAttribute( "style:name", TQString("co%1").arg(columnFormatIndex) );
columnFormatIndex++;
xmlWriter->startElement( "style:table-column-properties" );
xmlWriter->addAttribute( "fo:break-before", "auto" );
- xmlWriter->addAttribute( "style:column-width", TQString("%1in").tqarg(column->width()/27) );
+ xmlWriter->addAttribute( "style:column-width", TQString("%1in").arg(column->width()/27) );
xmlWriter->endElement(); // style:table-column-properties
xmlWriter->endElement(); // style:style
@@ -494,7 +494,7 @@ void ExcelImport::Private::processRowForBody( Row* row, int /*repeat*/, KoXmlWri
xmlWriter->startElement( "table:table-row" );
xmlWriter->addAttribute( "table:visibility", row->visible() ? "visible" : "collapse" );
- xmlWriter->addAttribute( "table:style-name", TQString("ro%1").tqarg(rowFormatIndex) );
+ xmlWriter->addAttribute( "table:style-name", TQString("ro%1").arg(rowFormatIndex) );
rowFormatIndex++;
for( int i = 0; i <= lastCol; i++ )
@@ -530,12 +530,12 @@ void ExcelImport::Private::processRowForStyle( Row* row, int repeat, KoXmlWriter
xmlWriter->startElement( "style:style" );
xmlWriter->addAttribute( "style:family", "table-row" );
if(repeat > 1) xmlWriter->addAttribute( "table:number-rows-repeated", repeat );
- xmlWriter->addAttribute( "style:name", TQString("ro%1").tqarg(rowFormatIndex) );
+ xmlWriter->addAttribute( "style:name", TQString("ro%1").arg(rowFormatIndex) );
rowFormatIndex++;
xmlWriter->startElement( "style:table-row-properties" );
xmlWriter->addAttribute( "fo:break-before", "auto" );
- xmlWriter->addAttribute( "style:row-height", TQString("%1pt").tqarg(row->height()) );
+ xmlWriter->addAttribute( "style:row-height", TQString("%1pt").arg(row->height()) );
xmlWriter->endElement(); // style:table-row-properties
xmlWriter->endElement(); // style:style
@@ -703,7 +703,7 @@ void ExcelImport::Private::processCellForStyle( Cell* cell, KoXmlWriter* xmlWrit
const UString& valueFormat = format.valueFormat();
if( !valueFormat.isEmpty() )
{
- refName = TQString("N%1").tqarg(cell->formatIndex());
+ refName = TQString("N%1").arg(cell->formatIndex());
TQString numformat = string( valueFormat ).string();
processValueFormat( numformat, refName, xmlWriter );
}
@@ -717,7 +717,7 @@ void ExcelImport::Private::processCellForStyle( Cell* cell, KoXmlWriter* xmlWrit
// now the real table-cell
xmlWriter->startElement( "style:style" );
xmlWriter->addAttribute( "style:family", "table-cell" );
- xmlWriter->addAttribute( "style:name", TQString("ce%1").tqarg( cell->formatIndex() ) );
+ xmlWriter->addAttribute( "style:name", TQString("ce%1").arg( cell->formatIndex() ) );
if( !refName.isEmpty() )
xmlWriter->addAttribute( "style:data-style-name", refName );
@@ -759,7 +759,7 @@ void ExcelImport::Private::processFormat( const Format* format, KoXmlWriter* xml
if( !xmlWriter ) return;
const FormatFont& font = format->font();
- const FormatAlignment& align = format->tqalignment();
+ const FormatAlignment& align = format->alignment();
const FormatBackground& back = format->background();
const FormatBorders& borders = format->borders();
@@ -792,7 +792,7 @@ void ExcelImport::Private::processFormat( const Format* format, KoXmlWriter* xml
if( !font.fontFamily().isEmpty() )
xmlWriter->addAttribute( "style:font-name", string(font.fontFamily()).string() );
- xmlWriter->addAttribute( "fo:font-size", TQString("%1pt").tqarg(font.fontSize()) );
+ xmlWriter->addAttribute( "fo:font-size", TQString("%1pt").arg(font.fontSize()) );
xmlWriter->addAttribute( "fo:color", convertColor( font.color() ) );
diff --git a/filters/kspread/excel/sidewinder/excel.cpp b/filters/kspread/excel/sidewinder/excel.cpp
index 651b7f2ce..6985a4342 100644
--- a/filters/kspread/excel/sidewinder/excel.cpp
+++ b/filters/kspread/excel/sidewinder/excel.cpp
@@ -5113,31 +5113,31 @@ bool ExcelReader::load( Workbook* workbook, const char* filename )
format.setFont( convertFont( xf.fontIndex() ) );
- FormatAlignment tqalignment;
+ FormatAlignment alignment;
switch( xf.horizontalAlignment() )
{
case XFRecord::Left:
- tqalignment.setAlignX( Format::Left ); break;
+ alignment.setAlignX( Format::Left ); break;
case XFRecord::Right:
- tqalignment.setAlignX( Format::Right ); break;
+ alignment.setAlignX( Format::Right ); break;
case XFRecord::Centered:
- tqalignment.setAlignX( Format::Center ); break;
+ alignment.setAlignX( Format::Center ); break;
default: break;
// FIXME still unsupported: Repeat, Justified, Filled, Distributed
};
switch( xf.verticalAlignment() )
{
case XFRecord::Top:
- tqalignment.setAlignY( Format::Top ); break;
+ alignment.setAlignY( Format::Top ); break;
case XFRecord::VCentered:
- tqalignment.setAlignY( Format::Middle ); break;
+ alignment.setAlignY( Format::Middle ); break;
case XFRecord::Bottom:
- tqalignment.setAlignY( Format::Bottom ); break;
+ alignment.setAlignY( Format::Bottom ); break;
default: break;
// FIXME still unsupported: Justified, Distributed
}
- tqalignment.setWrap( xf.textWrap() );
- format.setAlignment( tqalignment );
+ alignment.setWrap( xf.textWrap() );
+ format.setAlignment( alignment );
FormatBorders borders;
@@ -5929,31 +5929,31 @@ Format ExcelReader::convertFormat( unsigned xfIndex )
format.setFont( convertFont( xf.fontIndex() ) );
- FormatAlignment tqalignment;
+ FormatAlignment alignment;
switch( xf.horizontalAlignment() )
{
case XFRecord::Left:
- tqalignment.setAlignX( Format::Left ); break;
+ alignment.setAlignX( Format::Left ); break;
case XFRecord::Right:
- tqalignment.setAlignX( Format::Right ); break;
+ alignment.setAlignX( Format::Right ); break;
case XFRecord::Centered:
- tqalignment.setAlignX( Format::Center ); break;
+ alignment.setAlignX( Format::Center ); break;
default: break;
// FIXME still unsupported: Repeat, Justified, Filled, Distributed
};
switch( xf.verticalAlignment() )
{
case XFRecord::Top:
- tqalignment.setAlignY( Format::Top ); break;
+ alignment.setAlignY( Format::Top ); break;
case XFRecord::VCentered:
- tqalignment.setAlignY( Format::Middle ); break;
+ alignment.setAlignY( Format::Middle ); break;
case XFRecord::Bottom:
- tqalignment.setAlignY( Format::Bottom ); break;
+ alignment.setAlignY( Format::Bottom ); break;
default: break;
// FIXME still unsupported: Justified, Distributed
}
- tqalignment.setWrap( xf.textWrap() );
- format.setAlignment( tqalignment );
+ alignment.setWrap( xf.textWrap() );
+ format.setAlignment( alignment );
FormatBorders borders;
diff --git a/filters/kspread/excel/sidewinder/excel.h b/filters/kspread/excel/sidewinder/excel.h
index 8cbdfd538..c05d223b9 100644
--- a/filters/kspread/excel/sidewinder/excel.h
+++ b/filters/kspread/excel/sidewinder/excel.h
@@ -2805,17 +2805,17 @@ public:
Distributed };
/**
- * Gets the horizontal tqalignment, e.g Left.
+ * Gets the horizontal alignment, e.g Left.
*/
unsigned horizontalAlignment() const;
/**
- * Sets the horizontal tqalignment, e.g Left.
+ * Sets the horizontal alignment, e.g Left.
*/
void setHorizontalAlignment( unsigned ha );
/**
- * Returns human-readable string representation of the horizontal tqalignment.
+ * Returns human-readable string representation of the horizontal alignment.
For example, XFRecord::Left will return "Left".
*/
const char* horizontalAlignmentAsString() const;
@@ -2828,21 +2828,21 @@ public:
VDistributed = 4 };
/**
- * Gets the vertical tqalignment, e.g Bottom.
+ * Gets the vertical alignment, e.g Bottom.
*
* \sa setVerticalAlignment
*/
unsigned verticalAlignment() const;
/**
- * Sets the vertical tqalignment, e.g Top.
+ * Sets the vertical alignment, e.g Top.
*
* \sa verticalAlignment
*/
void setVerticalAlignment( unsigned va );
/**
- * Returns human-readable string representation of the vertical tqalignment.
+ * Returns human-readable string representation of the vertical alignment.
For example, XFRecord::Top will return "Top".
*/
const char* verticalAlignmentAsString() const;
diff --git a/filters/kspread/excel/sidewinder/format.cpp b/filters/kspread/excel/sidewinder/format.cpp
index b54f2a4c2..8ce69f248 100644
--- a/filters/kspread/excel/sidewinder/format.cpp
+++ b/filters/kspread/excel/sidewinder/format.cpp
@@ -271,7 +271,7 @@ FormatAlignment& FormatAlignment::operator=( const FormatAlignment& align )
return assign( align );
}
-// assign from another tqalignment
+// assign from another alignment
FormatAlignment& FormatAlignment::assign( const FormatAlignment& align )
{
d->null = align.isNull();
@@ -398,7 +398,7 @@ FormatBackground& FormatBackground::operator=( const FormatBackground& backgroun
return assign( background );
}
-// assign from another tqalignment
+// assign from another alignment
FormatBackground& FormatBackground::assign( const FormatBackground& background )
{
d->null = background.isNull();
@@ -498,7 +498,7 @@ FormatBorders& FormatBorders::operator=( const FormatBorders& border )
return assign( border );
}
-// assign from another tqalignment
+// assign from another alignment
FormatBorders& FormatBorders::assign( const FormatBorders& border )
{
d->null = border.isNull();
@@ -581,7 +581,7 @@ class Format::Private
{
public:
FormatFont font;
- FormatAlignment tqalignment;
+ FormatAlignment alignment;
FormatBorders borders;
FormatBackground background;
UString valueFormat;
@@ -617,7 +617,7 @@ Format& Format::operator=( const Format& f )
Format& Format::assign( const Format& f )
{
d->font = f.font();
- d->tqalignment = f.tqalignment();
+ d->alignment = f.alignment();
d->borders = f.borders();
d->valueFormat = f.valueFormat();
d->background = f.background();
@@ -626,7 +626,7 @@ Format& Format::assign( const Format& f )
bool Format::isNull() const
{
- return d->font.isNull() && d->tqalignment.isNull() && d->borders.isNull();
+ return d->font.isNull() && d->alignment.isNull() && d->borders.isNull();
}
FormatFont& Format::font() const
@@ -639,14 +639,14 @@ void Format::setFont( const FormatFont& font )
d->font = font;
}
-FormatAlignment& Format::tqalignment() const
+FormatAlignment& Format::alignment() const
{
- return d->tqalignment;
+ return d->alignment;
}
-void Format::setAlignment( const FormatAlignment& tqalignment )
+void Format::setAlignment( const FormatAlignment& alignment )
{
- d->tqalignment = tqalignment;
+ d->alignment = alignment;
}
FormatBorders& Format::borders() const
@@ -682,8 +682,8 @@ void Format::setValueFormat( const UString& valueFormat )
// merge f into current format
Format& Format::apply( const Format& f )
{
- if( !f.tqalignment().isNull() )
- tqalignment() = f.tqalignment();
+ if( !f.alignment().isNull() )
+ alignment() = f.alignment();
if( !f.font().isNull() )
font() = f.font();
if( !f.borders().isNull() )
@@ -700,7 +700,7 @@ bool Format::operator==(const Format& format) const
{
return
d->font == format.d->font &&
- d->tqalignment == format.d->tqalignment &&
+ d->alignment == format.d->alignment &&
d->borders == format.d->borders &&
d->background == format.d->background &&
d->valueFormat == format.d->valueFormat;
@@ -710,7 +710,7 @@ bool Format::operator!=(const Format& format) const
{
return
d->font != format.d->font ||
- d->tqalignment != format.d->tqalignment ||
+ d->alignment != format.d->alignment ||
d->borders != format.d->borders ||
d->background != format.d->background ||
d->valueFormat != format.d->valueFormat;
diff --git a/filters/kspread/excel/sidewinder/format.h b/filters/kspread/excel/sidewinder/format.h
index 1177b1bb7..acb566a51 100644
--- a/filters/kspread/excel/sidewinder/format.h
+++ b/filters/kspread/excel/sidewinder/format.h
@@ -266,9 +266,9 @@ private:
/**
- * Defines tqalignment information for cell format.
+ * Defines alignment information for cell format.
*
- * Class FormatAlignment defines the horizontal and vertical tqalignment
+ * Class FormatAlignment defines the horizontal and vertical alignment
* for the text inside a cell.
*
*/
@@ -278,37 +278,37 @@ class FormatAlignment
public:
/**
- * Creates a default tqalignment information.
+ * Creates a default alignment information.
*/
FormatAlignment();
/**
- * Destroys the tqalignment information
+ * Destroys the alignment information
*/
~FormatAlignment();
/**
- * Creates a copy of tqalignment information.
+ * Creates a copy of alignment information.
*/
FormatAlignment( const FormatAlignment& );
/**
- * Assigns from another tqalignment information.
+ * Assigns from another alignment information.
*/
FormatAlignment& operator=( const FormatAlignment& );
/**
- * Assigns from another tqalignment information.
+ * Assigns from another alignment information.
*/
FormatAlignment& assign( const FormatAlignment& );
/**
- * Returns true if it is a default tqalignment information.
+ * Returns true if it is a default alignment information.
*/
bool isNull() const;
/**
- * Returns horizontal tqalignment. Possible values are
+ * Returns horizontal alignment. Possible values are
* Format::Left, Format::Right and Format::Center.
*
* \sa setAlignX
@@ -316,14 +316,14 @@ public:
unsigned alignX() const;
/**
- * Sets the horizontal tqalignment.
+ * Sets the horizontal alignment.
*
* \sa alignX
*/
void setAlignX( unsigned xa );
/**
- * Returns horizontal tqalignment. Possible values are
+ * Returns horizontal alignment. Possible values are
* Format::Top, Format::Middle and Format::Bottom.
*
* \sa setAlignY
@@ -331,7 +331,7 @@ public:
unsigned alignY() const;
/**
- * Sets the horizontal tqalignment.
+ * Sets the horizontal alignment.
*
* \sa alignY
*/
@@ -380,12 +380,12 @@ public:
void setRotationAngle( unsigned r );
/**
- * Returns true if this tqalignment is equal to f; otherwise returns false.
+ * Returns true if this alignment is equal to f; otherwise returns false.
*/
bool operator==(const FormatAlignment& f) const;
/**
- * Returns true if this tqalignment is not equal to f; otherwise returns false.
+ * Returns true if this alignment is not equal to f; otherwise returns false.
*/
bool operator!=(const FormatAlignment& f) const;
@@ -683,14 +683,14 @@ public:
void setFont( const FormatFont& font );
/**
- * Returns a constant reference to the tqalignment information of this format.
+ * Returns a constant reference to the alignment information of this format.
*/
- FormatAlignment& tqalignment() const;
+ FormatAlignment& alignment() const;
/**
- * Sets new tqalignment information for this format.
+ * Sets new alignment information for this format.
*/
- void setAlignment( const FormatAlignment& tqalignment );
+ void setAlignment( const FormatAlignment& alignment );
/**
* Returns a reference to the borders information of this format.
diff --git a/filters/kspread/gnumeric/gnumeric.xsd b/filters/kspread/gnumeric/gnumeric.xsd
index 049490838..7150f7e45 100644
--- a/filters/kspread/gnumeric/gnumeric.xsd
+++ b/filters/kspread/gnumeric/gnumeric.xsd
@@ -427,8 +427,8 @@
</xsd:complexType>
</xsd:element>
</xsd:sequence>
- <xsd:attribute name="HAlign" type="gmr:horizontal_tqalignment"/>
- <xsd:attribute name="VAlign" type="gmr:vertical_tqalignment" />
+ <xsd:attribute name="HAlign" type="gmr:horizontal_alignment"/>
+ <xsd:attribute name="VAlign" type="gmr:vertical_alignment" />
<xsd:attribute name="WrapText" type="xsd:boolean" />
<xsd:attribute name="ShrinkToFit" type="xsd:integer" /> <!-- should be bool, but some files have odd truth values -->
<xsd:attribute name="Rotation" type="xsd:integer" use="optional"/>
@@ -492,7 +492,7 @@
</xsd:restriction>
</xsd:simpleType>
- <xsd:simpleType name="horizontal_tqalignment">
+ <xsd:simpleType name="horizontal_alignment">
<xsd:restriction base="xsd:integer">
<!-- this is a bit map as follows:
1 = GENERAL
@@ -508,7 +508,7 @@
</xsd:restriction>
</xsd:simpleType>
- <xsd:simpleType name="vertical_tqalignment">
+ <xsd:simpleType name="vertical_alignment">
<xsd:restriction base="xsd:integer">
<!-- this is a bit map as follows:
1 = TOP
@@ -644,7 +644,7 @@
<xsd:attribute name="FillColor" type="gmr:color" use="required"/>
<xsd:attribute name="Type" type="gmr:objectfilled" use="required"/>
<xsd:attribute name="Width" type="xsd:positiveInteger" use="required"/>
- <!-- the arrow tqshape attributes are only used if the type is
+ <!-- the arrow shape attributes are only used if the type is
arrow (type="gmr:2")
-->
<xsd:attribute name="ArrowShapeA" type="xsd:double" use="optional"/>
diff --git a/filters/kspread/gnumeric/gnumericexport.cc b/filters/kspread/gnumeric/gnumericexport.cc
index b56669162..b0709ede0 100644
--- a/filters/kspread/gnumeric/gnumericexport.cc
+++ b/filters/kspread/gnumeric/gnumericexport.cc
@@ -1443,7 +1443,7 @@ KoFilter::ConversionStatus GNUMERICExport::convert( const TQCString& from, const
//<gmr:CellComment Author="" Text="cvbcvbxcvb&#10;cb&#10;xc&#10;vbxcv&#10;" ObjectBound="A1" ObjectOffset="0 0 0 0" ObjectAnchorType="17 16 17 16" Direction="17"/>
cellComment = gnumeric_doc.createElement("gmr:CellComment");
cellComment.setAttribute( "Text", cell->format()->comment( currentcolumn, currentrow ) );
- TQString sCell=TQString( "%1%2" ).tqarg( Cell::columnName(currentcolumn ) ).tqarg( currentrow );
+ TQString sCell=TQString( "%1%2" ).arg( Cell::columnName(currentcolumn ) ).arg( currentrow );
cellComment.setAttribute("ObjectBound", sCell );
objects.appendChild(cellComment);
diff --git a/filters/kspread/html/exportdialog.cc b/filters/kspread/html/exportdialog.cc
index 72dd68755..8a0df7d0a 100644
--- a/filters/kspread/html/exportdialog.cc
+++ b/filters/kspread/html/exportdialog.cc
@@ -44,7 +44,7 @@ ExportDialog::ExportDialog( TQWidget *parent, const char *name )
m_mainwidget->mSheets, TQT_SLOT( clearSelection() ) );
m_mainwidget->mEncodingBox->insertItem( i18n( "Recommended: UTF-8" ) );
- m_mainwidget->mEncodingBox->insertItem( i18n( "Locale (%1)" ).tqarg( KGlobal::locale()->codecForEncoding()->name() ) );
+ m_mainwidget->mEncodingBox->insertItem( i18n( "Locale (%1)" ).arg( KGlobal::locale()->codecForEncoding()->name() ) );
m_mainwidget->mCustomURL->setMode( KFile::ExistingOnly );
diff --git a/filters/kspread/html/htmlexport.cc b/filters/kspread/html/htmlexport.cc
index b81d8e22a..f680207e4 100644
--- a/filters/kspread/html/htmlexport.cc
+++ b/filters/kspread/html/htmlexport.cc
@@ -186,7 +186,7 @@ void HTMLExport::openPage( Sheet *sheet, KoDocument *document, TQString &str )
str += "<html>\n";
str += "<head>\n";
str += "<meta http-equiv=\"Content-Type\" ";
- str += TQString("content=\"text/html; charset=%1\">\n").tqarg( m_dialog->encoding()->mimeName() );
+ str += TQString("content=\"text/html; charset=%1\">\n").arg( m_dialog->encoding()->mimeName() );
str += "<meta name=\"Generator\" ";
str += "content=\"KSpread HTML Export Filter Version = ";
str += KOFFICE_VERSION_STRING;
@@ -202,7 +202,7 @@ void HTMLExport::openPage( Sheet *sheet, KoDocument *document, TQString &str )
str += "<title>" + title + "</title>\n";
str += "</head>\n";
- str += TQString("<body bgcolor=\"#FFFFFF\" dir=\"%1\">\n").tqarg(
+ str += TQString("<body bgcolor=\"#FFFFFF\" dir=\"%1\">\n").arg(
sheet->isRightToLeft()?"rtl":"ltr");
str += "<a name=\"__top\">\n";
@@ -234,8 +234,8 @@ void HTMLExport::convertSheet( Sheet *sheet, TQString &str, int iMaxUsedRow, int
int step=iMaxRow > 50 ? iMaxRow/50 : 1;
int i=1;
- str += "<" + html_table_tag + html_table_options.tqarg( m_dialog->useBorders() ? "1" : "0" ).tqarg( m_dialog->pixelsBetweenCells() ) +
- TQString("dir=\"%1\">\n").tqarg(sheet->isRightToLeft()?"rtl":"ltr");
+ str += "<" + html_table_tag + html_table_options.arg( m_dialog->useBorders() ? "1" : "0" ).arg( m_dialog->pixelsBetweenCells() ) +
+ TQString("dir=\"%1\">\n").arg(sheet->isRightToLeft()?"rtl":"ltr");
unsigned int nonempty_cells_prev=0;
@@ -297,7 +297,7 @@ void HTMLExport::convertSheet( Sheet *sheet, TQString &str, int iMaxUsedRow, int
#endif
line += " <" + html_cell_tag + html_cell_options;
if (text.isRightToLeft() != sheet->isRightToLeft())
- line += TQString(" dir=\"%1\" ").tqarg(text.isRightToLeft()?"rtl":"ltr");
+ line += TQString(" dir=\"%1\" ").arg(text.isRightToLeft()?"rtl":"ltr");
if (bgcolor.isValid() && bgcolor.name()!="#ffffff") // change color only for non-white cells
line += " bgcolor=\"" + bgcolor.name() + "\"";
diff --git a/filters/kspread/latex/export/fileheader.cc b/filters/kspread/latex/export/fileheader.cc
index 8ee9eee0e..07b1fbe4e 100644
--- a/filters/kspread/latex/export/fileheader.cc
+++ b/filters/kspread/latex/export/fileheader.cc
@@ -79,7 +79,7 @@ void FileHeader::analysePaper(const TQDomNode balise)
analysePaperParam(balise);
//setTokenCurrent(balise_initiale->pContent);
- // Analyse tqchildren markups --> PAPERBORDERS
+ // Analyse children markups --> PAPERBORDERS
TQDomNode fils = getChild(balise, "PAPERSBORDERS");
_leftBorder = getAttr(fils, "left").toInt();
_rightBorder = getAttr(fils, "right").toInt();
@@ -282,7 +282,7 @@ void FileHeader::generatePackage(TQTextStream &out)
if(Config::instance()->mustUseUnicode())
out << "\\usepackage{omega}" << endl;
if(getFormat() == TF_A4)
- out << "\\usepackage[a4paper]{tqgeometry}" << endl;
+ out << "\\usepackage[a4paper]{geometry}" << endl;
if(hasFooter() || hasHeader())
out << "\\usepackage{fancyhdr}" << endl;
if(hasColor())
diff --git a/filters/kspread/latex/export/kspreadlatexexportdiaImpl.cc b/filters/kspread/latex/export/kspreadlatexexportdiaImpl.cc
index a7f03f60a..7713a9dc4 100644
--- a/filters/kspread/latex/export/kspreadlatexexportdiaImpl.cc
+++ b/filters/kspread/latex/export/kspreadlatexexportdiaImpl.cc
@@ -69,7 +69,7 @@ KSpreadLatexExportDiaImpl::KSpreadLatexExportDiaImpl(KoStore* in, TQWidget* pare
TQString value;
while(i < 10)
{
- /*value = _config->readPathEntry( TQString("Recent%1").tqarg(i) );
+ /*value = _config->readPathEntry( TQString("Recent%1").arg(i) );
kdDebug(30522) << "recent : " << value << endl;
if(!value.isEmpty())
{
diff --git a/filters/kspread/latex/export/map.cc b/filters/kspread/latex/export/map.cc
index a2256d5ec..886f6c115 100644
--- a/filters/kspread/latex/export/map.cc
+++ b/filters/kspread/latex/export/map.cc
@@ -46,7 +46,7 @@ void Map::analyse(const TQDomNode balise)
/* Analyse of the parameters */
kdDebug(30522) << "ANALYSE A MAP" << endl;
- /* Analyse of the tqchildren markups */
+ /* Analyse of the children markups */
for(int index = 0; index < getNbChild(balise); index++)
{
// Only tables
diff --git a/filters/kspread/latex/export/xmlparser.cc b/filters/kspread/latex/export/xmlparser.cc
index 6b85f243c..fb2c8e1f2 100644
--- a/filters/kspread/latex/export/xmlparser.cc
+++ b/filters/kspread/latex/export/xmlparser.cc
@@ -89,18 +89,18 @@ bool XmlParser::isChild(TQDomNode balise, TQString name)
TQDomNode XmlParser::getChild(TQDomNode balise, TQString name, int index)
{
if(balise.isElement()) {
- TQDomNodeList tqchildren = balise.toElement().elementsByTagName(name);
- if ( tqchildren.count() )
- return tqchildren.item(index);
+ TQDomNodeList children = balise.toElement().elementsByTagName(name);
+ if ( children.count() )
+ return children.item(index);
}
return TQDomNode();
}
TQDomNode XmlParser::getChild(TQDomNode balise, int index)
{
- TQDomNodeList tqchildren = balise.childNodes();
- if ( tqchildren.count() )
- return tqchildren.item(index);
+ TQDomNodeList children = balise.childNodes();
+ if ( children.count() )
+ return children.item(index);
return TQDomNode();
}
diff --git a/filters/kspread/opencalc/opencalcexport.cc b/filters/kspread/opencalc/opencalcexport.cc
index 828d817ae..ce1a55ad6 100644
--- a/filters/kspread/opencalc/opencalcexport.cc
+++ b/filters/kspread/opencalc/opencalcexport.cc
@@ -844,7 +844,7 @@ void OpenCalcExport::exportDefaultCellStyle( TQDomDocument & doc, TQDomElement &
TQDomElement style = doc.createElement( "style:properties" );
style.setAttribute( "style:font-name", font.family() );
- style.setAttribute( "fo:font-size", TQString( "%1pt" ).tqarg( font.pointSize() ) );
+ style.setAttribute( "fo:font-size", TQString( "%1pt" ).arg( font.pointSize() ) );
style.setAttribute( "style:decimal-places", TQString::number( locale->fracDigits() ) );
style.setAttribute( "fo:language", language );
style.setAttribute( "fo:country", country );
@@ -881,8 +881,8 @@ void OpenCalcExport::exportPageAutoStyles( TQDomDocument & doc, TQDomElement & a
height = sheet->print()->paperHeight() / 10;
}
- TQString sWidth = TQString( "%1cm" ).tqarg( width );
- TQString sHeight = TQString( "%1cm" ).tqarg( height );
+ TQString sWidth = TQString( "%1cm" ).arg( width );
+ TQString sHeight = TQString( "%1cm" ).arg( height );
TQDomElement pageMaster = doc.createElement( "style:page-master" );
pageMaster.setAttribute( "style:name", "pm1" );
diff --git a/filters/kspread/opencalc/opencalcimport.cc b/filters/kspread/opencalc/opencalcimport.cc
index 0fbe52e01..8e0327c9c 100644
--- a/filters/kspread/opencalc/opencalcimport.cc
+++ b/filters/kspread/opencalc/opencalcimport.cc
@@ -1387,7 +1387,7 @@ void OpenCalcImport::loadOasisMasterLayoutPage( Sheet * table,KoStyleStack &styl
kdDebug(30518)<<" table-centering unknown :"<<str<<endl;
#endif
}
- format = TQString( "%1x%2" ).tqarg( width ).tqarg( height );
+ format = TQString( "%1x%2" ).arg( width ).arg( height );
kdDebug(30518)<<" format : "<<format<<endl;
table->print()->setPaperLayout( left, top, right, bottom, format, orientation );
@@ -2289,7 +2289,7 @@ bool OpenCalcImport::createStyleMap( TQDomDocument const & styles )
if ( d > 1.0 )
{
TQString message( i18n("This document was created with OpenOffice.org version '%1'. This filter was written for version 1.0. Reading this file could cause strange behavior, crashes or incorrect display of the data. Do you want to continue converting the document?") );
- message.tqarg( content.attributeNS( ooNS::office, "version", TQString() ) );
+ message.arg( content.attributeNS( ooNS::office, "version", TQString() ) );
if ( KMessageBox::warningYesNo( 0, message, i18n( "Unsupported document version" ) ) == KMessageBox::No )
return false;
}
diff --git a/filters/kspread/opencalc/opencalcstyleexport.cc b/filters/kspread/opencalc/opencalcstyleexport.cc
index f075713a6..9585ae139 100644
--- a/filters/kspread/opencalc/opencalcstyleexport.cc
+++ b/filters/kspread/opencalc/opencalcstyleexport.cc
@@ -111,7 +111,7 @@ TQString OpenCalcStyles::cellStyle( CellStyle const & cs )
m_cellStyles.append( t );
- t->name = TQString( "ce%1" ).tqarg( m_cellStyles.count() );
+ t->name = TQString( "ce%1" ).arg( m_cellStyles.count() );
return t->name;
}
@@ -132,7 +132,7 @@ TQString OpenCalcStyles::columnStyle( ColumnStyle const & cs )
m_columnStyles.append( t );
- t->name = TQString( "co%1" ).tqarg( m_columnStyles.count() );
+ t->name = TQString( "co%1" ).arg( m_columnStyles.count() );
return t->name;
}
@@ -158,7 +158,7 @@ TQString OpenCalcStyles::rowStyle( RowStyle const & rs )
m_rowStyles.append( t );
- t->name = TQString( "ro%1" ).tqarg( m_rowStyles.count() );
+ t->name = TQString( "ro%1" ).arg( m_rowStyles.count() );
return t->name;
}
@@ -179,14 +179,14 @@ TQString OpenCalcStyles::sheetStyle( SheetStyle const & ts )
m_sheetStyles.append( t );
- t->name = TQString( "ta%1" ).tqarg( m_sheetStyles.count() );
+ t->name = TQString( "ta%1" ).arg( m_sheetStyles.count() );
return t->name;
}
TQString convertPenToString( TQPen const & pen )
{
- TQString s( TQString( "%1cm solid " ).tqarg( pen.width() * 0.035 ) );
+ TQString s( TQString( "%1cm solid " ).arg( pen.width() * 0.035 ) );
s += pen.color().name();
return s;
@@ -212,7 +212,7 @@ void OpenCalcStyles::addCellStyles( TQDomDocument & doc, TQDomElement & autoStyl
if ( t->font.bold() != m_defaultFont.bold() )
prop.setAttribute( "fo:font-weight", ( t->font.bold() ? "bold" : "light" ) );
- prop.setAttribute( "fo:font-size", TQString( "%1pt" ).tqarg( t->font.pointSize() ) );
+ prop.setAttribute( "fo:font-size", TQString( "%1pt" ).arg( t->font.pointSize() ) );
if ( t->font.underline() != m_defaultFont.underline() )
{
@@ -250,7 +250,7 @@ void OpenCalcStyles::addCellStyles( TQDomDocument & doc, TQDomElement & autoStyl
if ( t->indent > 0.0 )
{
- prop.setAttribute( "fo:margin-left", TQString( "%1pt" ).tqarg( t->indent ) );
+ prop.setAttribute( "fo:margin-left", TQString( "%1pt" ).arg( t->indent ) );
if ( t->alignX == Format::Undefined )
prop.setAttribute( "fo:text-align", "start" );
}
@@ -323,7 +323,7 @@ void OpenCalcStyles::addColumnStyles( TQDomDocument & doc, TQDomElement & autoSt
TQDomElement prop = doc.createElement( "style:properties" );
if ( t->breakB != ::Style::none )
prop.setAttribute( "fo:break-before", ( t->breakB == ::Style::automatic ? "auto" : "page" ) );
- prop.setAttribute( "style:column-width", TQString( "%1cm" ).tqarg( t->size ) );
+ prop.setAttribute( "style:column-width", TQString( "%1cm" ).arg( t->size ) );
ts.appendChild( prop );
autoStyles.appendChild( ts );
@@ -346,7 +346,7 @@ void OpenCalcStyles::addRowStyles( TQDomDocument & doc, TQDomElement & autoStyle
ts.setAttribute( "style:family", "table-row" );
TQDomElement prop = doc.createElement( "style:properties" );
- prop.setAttribute( "style:row-height", TQString( "%1cm" ).tqarg( t->size ) );
+ prop.setAttribute( "style:row-height", TQString( "%1cm" ).arg( t->size ) );
if ( t->breakB != ::Style::none )
prop.setAttribute( "fo:break-before", ( t->breakB == ::Style::automatic ? "auto" : "page" ) );
diff --git a/filters/kspread/opencalc/status.html b/filters/kspread/opencalc/status.html
index dfaed8a4b..2bd1fc05b 100644
--- a/filters/kspread/opencalc/status.html
+++ b/filters/kspread/opencalc/status.html
@@ -139,7 +139,7 @@ KOffice filters status:&nbsp;&nbsp; OpenOffice.org Calc</h1></center>
Page sizes, header and footer (including variable converting)<br>
Font (sizes, attributes, color)<br>
Background color<br>
- Text tqalignment, angle, vertical text, text wrap and indents<br>
+ Text alignment, angle, vertical text, text wrap and indents<br>
Merged Cells<br>
DontPrint flag<br>
Comments<br>
@@ -172,7 +172,7 @@ KOffice filters status:&nbsp;&nbsp; OpenOffice.org Calc</h1></center>
Jan 18, 2003 - page tqlayout, header, footer<br>
Jan 19, 2003 - Added support for fonts, text color, background color, formula
conversion<br>
- Jan 19, 2003 - text tqalignment, indents, comments, NoPrint, Merged Cells<br>
+ Jan 19, 2003 - text alignment, indents, comments, NoPrint, Merged Cells<br>
Jan 19, 2003 - angle, vertical text, text wrap<br>
Jan 19, 2003 - named area, hidden columns and rows<br>
Jan 20, 2003 - cell borders<br>
diff --git a/filters/kspread/excel/sidewinder/pole.cpp b/filters/kspread/excel/sidewinder/pole.cpp
index 38fe8cb55..6f12ae139 100644
--- a/filters/kspread/excel/sidewinder/pole.cpp
+++ b/filters/kspread/excel/sidewinder/pole.cpp
@@ -116,7 +116,7 @@ class DirTree
int indexOf( DirEntry* e );
int parent( unsigned index );
std::string fullName( unsigned index );
- std::vector<unsigned> tqchildren( unsigned index );
+ std::vector<unsigned> children( unsigned index );
void load( unsigned char* buffer, unsigned len );
void save( unsigned char* buffer );
unsigned size();
@@ -509,11 +509,11 @@ int DirTree::indexOf( DirEntry* e )
int DirTree::parent( unsigned index )
{
// brute-force, basically we iterate for each entries, find its tqchildren
// and check if one of the tqchildren is 'index'
for( unsigned j=0; j<entryCount(); j++ )
{
- std::vector<unsigned> chi = tqchildren( j );
+ std::vector<unsigned> chi = children( j );
for( unsigned i=0; i<chi.size();i++ )
if( chi[i] == index )
return j;
@@ -577,8 +577,8 @@ DirEntry* DirTree::entry( const std::string& name, bool create )
for( it = names.begin(); it != names.end(); ++it )
{
- // find among the tqchildren of index
- std::vector<unsigned> chi = tqchildren( index );
+ // find among the children of index
+ std::vector<unsigned> chi = children( index );
unsigned child = 0;
for( unsigned i = 0; i < chi.size(); i++ )
{
@@ -593,7 +593,7 @@ DirEntry* DirTree::entry( const std::string& name, bool create )
if( child > 0 ) index = child;
else
{
// not found among tqchildren
if( !create ) return (DirEntry*)0;
// create a new entry
@@ -650,7 +650,7 @@ void dirtree_find_siblings( DirTree* dirtree, std::vector<unsigned>& result,
}
}
-std::vector<unsigned> DirTree::tqchildren( unsigned index )
+std::vector<unsigned> DirTree::children( unsigned index )
{
std::vector<unsigned> result;
@@ -1286,9 +1286,9 @@ std::list<std::string> Storage::entries( const std::string& path )
if( e && e->dir )
{
unsigned parent = dt->indexOf( e );
- std::vector<unsigned> tqchildren = dt->tqchildren( parent );
- for( unsigned i = 0; i < tqchildren.size(); i++ )
- result.push_back( dt->entry( tqchildren[i] )->name );
+ std::vector<unsigned> children = dt->children( parent );
+ for( unsigned i = 0; i < children.size(); i++ )
+ result.push_back( dt->entry( children[i] )->name );
}
return result;
@@ -509,11 +509,11 @@ int DirTree::indexOf( DirEntry* e )
int DirTree::parent( unsigned index )
{
- // brute-force, basically we iterate for each entries, find its tqchildren
- // and check if one of the tqchildren is 'index'
+ // brute-force, basically we iterate for each entries, find its children
+ // and check if one of the children is 'index'
for( unsigned j=0; j<entryCount(); j++ )
{
@@ -593,7 +593,7 @@ DirEntry* DirTree::entry( const std::string& name, bool create )
else
{
- // not found among tqchildren
+ // not found among children
if( !create ) return (DirEntry*)0;
// create a new entry